package com.atlassian.elasticsearch.buckler.security;

import java.util.Date;
import java.util.concurrent.atomic.AtomicInteger;

class AuthRecord {

    private final AtomicInteger failedAttempts;
    private volatile Date lastFailure;

    AuthRecord() {
        this.failedAttempts = new AtomicInteger(0);
        lastFailure = new Date();
    }

    public Date getLastFailure() {
        return lastFailure;
    }

    public void newAttempt() {
        while (true) {
            int oldValue = failedAttempts.get();
            if (failedAttempts.compareAndSet(oldValue, oldValue + 1)) {
                lastFailure = new Date();
                return;
            }
        }
    }

    int getFailureCount() {
        return failedAttempts.get();
    }
}
