package com.atlassian.elasticsearch.buckler.security;

import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.http.HttpRequest;
import org.elasticsearch.rest.RestRequest;
import org.elasticsearch.transport.TransportRequest;

public class RequestIdentifier {

    private static final String ANONYMOUS_ID = "ANONYMOUS";

    private final boolean anonymous;
    private final String identifier;

    private RequestIdentifier(String identifier, boolean anonymous) {
        this.identifier = identifier;
        this.anonymous = anonymous;
    }

    public static RequestIdentifier from(ChannelHandlerContext context, HttpRequest request) {
        if (context.channel().remoteAddress() == null) {
            return new RequestIdentifier(ANONYMOUS_ID, true);
        }
        // getRemoteAddress is in the form (ip|hostname):port
        // as the port may change constantly, we need to just get the ip part
        return new RequestIdentifier(context.channel().remoteAddress().toString().split(":")[0], false);
    }

    public static RequestIdentifier from(TransportRequest request) {
        if (request.remoteAddress() == null || request.remoteAddress().address().getHostName() == null) {
            return new RequestIdentifier(ANONYMOUS_ID, true);
        }
        return new RequestIdentifier(request.remoteAddress().address().getHostName().toLowerCase(), false);
    }

    public static RequestIdentifier from(RestRequest request) {
        if(request.getRemoteAddress() != null) {
            return new RequestIdentifier(request.getRemoteAddress().toString(), false);
        }
        return new RequestIdentifier(ANONYMOUS_ID, true);
    }

    public String getIdentifier() {
        return identifier;
    }

    public boolean isAnonymous() {
        return anonymous;
    }
}
